@@ -1,5 +1,5 @@
 package Hailo::Test;
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use 5.010;
 use autodie;
 use Any::Moose;
@@ -26,8 +26,6 @@ sub all_tests {
     return qw(test_starcraft test_congress test_congress_unknown test_babble test_badger test_megahal);
 }
 
-sub all_tests_known { return grep { $_ !~ /unknown/ } all_tests() }
-
 has brief => (
     is => 'ro',
     isa => 'Bool',
@@ -406,30 +404,33 @@ sub test_starcraft {
 }
 
 sub test_all_plan {
-    my ($self, $restriction) = @_;
-    my $storage = $self->storage;    
+    my ($self) = @_;
+    my $storage = $self->storage;
 
   SKIP: {
     my $ok = $self->spawn_storage();
 
     plan skip_all => "Skipping $storage tests, can't create storage" unless $ok;
-    if (defined $restriction && $restriction eq 'known') {
-        plan(tests => 951);
-        $self->test_known;
-    }
-    else {
-        plan(tests => 952);
-        $self->test_all;
-    }
+    plan(tests => 977);
+    $self->test_all;
   }
 }
 
-sub test_known {
-    my ($self) = @_;
+sub test_stats {
+    my ($self, $test_name) = @_;
+    state $last_token = 0;
+    state $last_expr = 0;
+    state $last_prev = 0;
+    state $last_next = 0;
 
-    for (all_tests_known()) {
-        $self->$_;
-    }
+    my ($token, $expr, $prev, $next) = $self->hailo->stats();
+
+    cmp_ok($last_token, "<=", $token, "token count is <= since last time from $last_token to $token");
+    cmp_ok($last_expr, "<=", $expr, "expr count is <= since last time from $last_expr to $expr");
+    cmp_ok($last_prev, "<=", $prev, "prev count is <= since last time from $last_prev to $prev");
+    cmp_ok($last_next, "<=", $next, "next count is <= since last time from $last_next to $next");
+
+    ($last_token, $last_expr, $last_prev, $last_next) = ($token, $expr, $prev, $next);
 
     return;
 }
@@ -437,8 +438,11 @@ sub test_known {
 sub test_all {
     my ($self) = @_;
 
+    ok($self->hailo->_storage_obj->ready(), "Storage object is ready for testing");
+
     for (all_tests()) {
         $self->$_;
+        $self->test_stats($_);
     }
 
     return;
